#
# Setup script for EdkDSP development environment.
# Run using 'source ./settings.sh'
#

script_name='settings.sh'

#
# Make sure our current working directory represents
# a valid EdkDSP environment.
#
if [ ! -f $script_name ]; then

  echo
  echo Please change to the root directory of your EdkDSP environment
  echo environment and type \'source ./$script_name\'.
  echo

#
# And check that we are being run using 'source ./file' rather
# than 'sh ./file'.
#
elif [ `basename $0` == $script_name ]; then

  echo
  echo Please use \'source ./$script_name\'.
  echo

else

  EDKDSP=`pwd`
  export EDKDSP
  export EDKDSP_VER=1.00

  # Figure out host system architecture
  # for now, only linux-i386 supported
  HOSTARCH=linux-i386

  #
  # Add required binary tools to the user's search path
  #
  PATH=$EDKDSP/tools/${HOSTARCH}/utia/bin:$PATH

  #
  # Check for "." or ".\" in the path - it's broken
  #
  echo $PATH | tr ":" "\n" | grep '^\./*$' > /dev/null && 
	echo "WARNING: '.' detected in PATH - fixing it." 1>&2
  PATH=`echo ${PATH} | tr ":" "\n" | grep -v '^\./*$' | tr "\n" ":"`

  export PATH

  echo EdkDSP environment set to \'$EDKDSP\'

  
fi

